function [mx,my]=detectMovementByFourier(mat)
% detection of linear motion in maties
% as described in Gonzales / Woods: Digital Image Processing
% 10.6.2: Frequency Domain Techniques of Segmentation
% Input: movie, given as matrix of grayvalue images
% Output: independent(!) vectors of x,y movement

a=4;    % base frequency. This parameter is critical and
        % experimentally determined

% some onvenient variables        
sizeX = size(mat,2);
sizeY = size(mat,1);
nof =   size(mat,3); % number of frames

% x direction movement
x=sin(0 : 2*pi*a/(sizeX-1) : 2*pi*a);
for t=1:nof
    frame=mat(:,:,t);   % extract single frame t
    px=sum(frame);      % projection
    gx(t)=x * px'; % sin. multiplication + sum
end
fx=abs(fft(gx));        % fourier transform
% result preparation
fx1=fx > 2*mean(fx(2:end)); % threshold to cut high freq.
maxIndex=max(find(fx1(1:end/2)));
fx=fx(1:maxIndex);          % cut fourier coeff. vector
fx1=fx1(1:maxIndex);        % cut index vector
fx=fx/max(fx(2:end));       % normalize

% y direction: same as x...
% could have been programmed as local function !
y=sin(0 : 2*pi*a/(sizeY-1) : 2*pi*a);
for t=1:nof
    frame=mat(:,:,t);
    py=sum(frame');     % projection: transpose !
    gy(t)=y * py';    
end
fy=abs(fft(gy));
fy1=fy > 2*mean(fy(2:end));
maxIndex=max(find(fy1(1:end/2)));
fy=fy(1:maxIndex);
fy1=fy1(1:maxIndex);
fy=fy/max(fy(2:end));

% result
mx=(find(fx1)-1)*sizeX / (a * nof); % transpose freq.
my=(find(fy1)-1)*sizeY / (a * nof);


% plot
subplot(2,2,1);plot(1:nof,gx);
subplot(2,2,2);bar(0:length(fx)-1,fx(1:end));axis([0 length(fx) 0 1]);
subplot(2,2,3);plot(1:nof,gy);
subplot(2,2,4);bar(0:length(fy)-1,fy(1:end));axis([0 length(fy) 0 1]);

% good bye
return
